import { Component, Inject, OnInit, PLATFORM_ID } from '@angular/core';
import { ApiAuthenticationService } from '../shared/services/api/api-authentication.service';
import { MatCardModule } from '@angular/material/card';
import { MatSelectModule } from '@angular/material/select';
import { HttpClient } from '@angular/common/http';
import { isPlatformBrowser } from '@angular/common';
import { environment } from '../../environments/environment';
import EventService from '../shared/services/EventService';
import { HermesClientService } from '../hermes-client.service';
import { Router } from '@angular/router';

@Component({
    selector: 'impersonation',
    imports: [MatCardModule, MatSelectModule],
    templateUrl: './impersonation.component.html',
    styleUrl: './impersonation.component.scss'
})
export class ImpersonationComponent implements OnInit {
    impersonated: string | undefined;
    users: { id: string, name: string }[];

    constructor(private hermes: HermesClientService, private auth: ApiAuthenticationService, private router: Router, private events: EventService, private http: HttpClient, @Inject(PLATFORM_ID) private platformId: Object) {
        this.users = []
    }

    ngOnInit(): void {
        if (!isPlatformBrowser(this.platformId)) {
            return;
        }

        this.http.get(environment.API_HOST + '/admin/users', {
            headers: {
                'Authorization': 'Bearer ' + localStorage.getItem('jwt')
            }
        }).subscribe((data: any) => {
            this.users = data.filter((d: any) => d.name != this.auth.getUsername());
            const id = this.auth.getImpersonatedId();
            if (id && this.users.find(u => u.id == id)) {
                this.impersonated = id;
            }
        });
    }

    public isAdmin() {
        return this.auth.isAdmin();
    }

    public getUsername() {
        return this.auth.getUsername();
    }

    public onChange(e: any) {
        console.log('impersonate befre', e.value);
        if (!e.value) {
            this.http.delete(environment.API_HOST + '/admin/impersonate', {
                headers: {
                    'Authorization': 'Bearer ' + localStorage.getItem('jwt')
                },
                body: {
                    impersonation: e.value
                }
            }).subscribe((data: any) => {
                this.hermes.disconnect();
                this.events.emit('impersonation', e.value);
                this.router.navigate(['/tts-login']);
            });
        } else {
            this.http.put(environment.API_HOST + '/admin/impersonate', {
                impersonation: e.value
            }, {
                headers: {
                    'Authorization': 'Bearer ' + localStorage.getItem('jwt')
                }
            }).subscribe((data: any) => {
                this.hermes.disconnect();
                this.events.emit('impersonation', e.value);
                this.router.navigate(['/tts-login']);
            });
        }
    }
}
