import { Component, EventEmitter, inject, Input, OnInit, Output, signal } from '@angular/core';
import { Filter, FilterFlag } from '../../shared/models/filter';
import { MatCardModule } from '@angular/material/card';
import { MatMenuModule } from '@angular/material/menu';
import { MatIconModule } from '@angular/material/icon';
import { MatDialog } from '@angular/material/dialog';
import { FilterItemEditComponent } from '../filter-item-edit/filter-item-edit.component';
import { MatButtonModule } from '@angular/material/button';
import { HermesClientService } from '../../hermes-client.service';

@Component({
    selector: 'tts-filter-item',
    standalone: true,
    imports: [MatButtonModule, MatCardModule, MatMenuModule, MatIconModule],
    templateUrl: './filter-item.component.html',
    styleUrl: './filter-item.component.scss'
})
export class FilterItemComponent implements OnInit {
  @Input() item: Filter = { id: "", user_id: "", search: "", replace: "", flag: FilterFlag.None, is_regex: false };
  @Output() onDelete = new EventEmitter<Filter>();
  readonly client = inject(HermesClientService);
  readonly dialog = inject(MatDialog);
  private loaded = false;


  ngOnInit(): void {
    this.loaded = true;
  }

  openDialog(): void {
    if (!this.loaded)
      return;

    const dialogRef = this.dialog.open(FilterItemEditComponent, {
      data: { id: this.item.id, search: this.item.search, replace: this.item.replace },
    });

    dialogRef.afterClosed().subscribe((result: Filter) => {
      if (result !== undefined) {
        console.log('update filter', result);
        this.client.first((d: any) => d.op == 4 && d.d.request.type == 'update_tts_filter' && d.d.data.id == this.item.id)
          ?.subscribe(_ => {
            this.item.search = result.search;
            this.item.replace = result.replace;
          });
        this.client.updateTTSFilter(this.item.id, result.search, result.replace);
      }
    });
  }
}